Annotations — BCI-Framework documentation

# Annotations

class `bci_framework.framework.widgets.annotations.` `Annotations`(parent, core)

  Widget connected with Kafka to stream messages.

  `__init__`(parent, core)

    Constructor

  `add_annotation`(onset, duration: str, description: str, action: Optional[bool] = True) → None

    Write the annotation in the GUI.

  `add_command`(onset: str, command: str) → None

    Write the command in the GUI.

  `add_marker`(onset: str, marker: str, timestamp: Optional[bool] = True) → None

    Write the marker in the GUI.

  `connect`() → None

    Connect events.

  `save_annotation`() → None

    Write the annotation in the streaming.

  `save_command`() → None

    Write the command in the streaming.

  `save_marker`() → None

    Write the marker in the streaming.